@@ -1,9 +1,9 @@
 package VCS::CMSynergy;
 
-# Copyright (c) 2001-2013 argumentum GmbH
+# Copyright (c) 2001-2015 argumentum GmbH
 # See COPYRIGHT section in VCS/CMSynergy.pod for usage and distribution rights.
 
-our $VERSION = '1.42';
+our $VERSION = '1.43';
 
 use 5.008_001;                          # i.e. v5.8.1
 use strict;
@@ -95,20 +95,28 @@ sub _start
     $self->{env} = { %{ $client->{env} } } if $client->{env};
     bless $self, $class;
 
-    # prime web_mode and ccm_addr as early as possible
+    # remember the process that created $self (so we can check in DESTROY)
+    $self->{pid} = $$;
+
+    # prime web_mode early as possible
     $self->{web_mode} = 1 if $self->version >= 7.2;
-    $self->{env}->{CCM_ADDR} = delete $args{CCM_ADDR} if defined $args{CCM_ADDR};
 
     foreach (qw( KeepSession UseCoprocess ))
     {
         $self->{$_} = delete $args{$_} if exists $args{$_};
     }
 
-    if (defined(my $ccm_addr = $self->ccm_addr))  # reuse an existing Synergy session
+    if (defined(my $ccm_addr = delete $args{CCM_ADDR}))  # reuse an existing Synergy session
     {
         # NOTE: Web mode may be determined (if still unknown) via "ccm ps".
-        croak(__PACKAGE__.qq[::_start: can't find session "$ccm_addr" in "ccm ps"])
-              unless $self->_my_ps();
+
+        # fail early if CCM_ADDR is bogus
+        my $ps = $self->ps(rfc_address => $ccm_addr);
+        return $self->set_error(qq[can't find session "$ccm_addr" in "ccm ps"]) 
+            unless $ps && @$ps;
+
+        $self->{env}{CCM_ADDR} = $ccm_addr;
+        $self->{web_mode} = $ps->[0]{process} eq "usr_cmd_interface";
 
         # anything still left in %args is an error
         croak(__PACKAGE__."::_start: option(s) not valid when CCM_ADDR is specified: ".
@@ -212,7 +220,7 @@ sub _start
         my ($rc, $out, $err) = $self->_ccm(@start);
         return $self->set_error($err || $out) unless $rc == 0;
 
-        $self->{env}->{CCM_ADDR} = $out;
+        $self->{env}{CCM_ADDR} = $out;
         INFO qq[started session "$out"];
     }
 
@@ -239,13 +247,9 @@ sub _start
     # or the user's personal ccm.ini its "User" setting will be used
     # and may trigger the "security violation".
 
-    $self->{env}->{CCM_INI_FILE} = $self->{ini_file}
+    $self->{env}{CCM_INI_FILE} = $self->{ini_file}
         if is_win32 && !$self->web_mode;
 
-    # remember the process that created $self (so we can check in DESTROY)
-    $self->{pid} = $$;
-
-
     # web mode renames the %filename placeholder (cf. "ccm set text_editor")
     $self->{"%filename"} = $self->web_mode ? "%file" : "%filename";
 
@@ -349,13 +353,12 @@ sub DESTROY
 }
 
 
-sub ccm_addr    { return shift->{env}->{CCM_ADDR}; }
+sub ccm_addr    { return shift->{env}{CCM_ADDR}; }
 
 sub delimiter   { return shift->{delimiter}; }
 
-# find my session's entry in "ccm ps";
-# if FIELD was specified, return the value of tthat field;
-# otherwise return true if my session was found, false otherwise
+# find my session's entry in "ccm ps" and return the value of $field
+# returns undef (or throws an error) if the session can't be found
 sub _my_ps
 { 
     my $self = shift;
@@ -363,10 +366,10 @@ sub _my_ps
 
     my $ccm_addr = $self->ccm_addr;
     my $ps = $self->ps(rfc_address => $ccm_addr);
-    return $ps && @$ps if @_ == 0;
-    return $self->set_error(qq[can't find current session "$ccm_addr" in "ccm ps"]) 
+    return $self->set_error(qq[can't find session "$ccm_addr" in "ccm ps"]) 
         unless $ps && @$ps;
-    return $ps->[0]->{$field};
+
+    return $ps->[0]{$field};
 }
 
 # determine database path (in canonical format) etc from "ccm ps"
