@@ -1,6 +1,6 @@
 package VCS::CMSynergy::Client;
 
-# Copyright (c) 2001-2014 argumentum GmbH
+# Copyright (c) 2001-2015 argumentum GmbH
 # See COPYRIGHT section in VCS/CMSynergy.pod for usage and distribution rights.
 
 =head1 NAME
@@ -186,10 +186,11 @@ sub ccm						# class/instance method
 
     my ($rc, $out, $err) = $this->_ccm(@_);
 
-    return wantarray ? ($rc, $out, $err) : $rc == 0 if defined wantarray;
-    # NOTE: "defined wantarray" checks if we're called in non-void context
-    return $this->set_error($err || $out, undef, 0, $rc, $out, $err);
-    # NOTE: most failing ccm commands issue their error messages on stdout!
+    # Note: "defined wantarray" checks if we're called in non-void context
+    return wantarray ? ($rc, $out, $err) : $rc == 0 
+        if defined wantarray;
+
+    $this->set_error($err || $out) unless $rc == 0;
 }
 
 
